@@ -20,15 +20,16 @@
 #ifndef PASSWORDFILTERMODEL_H_
 #define PASSWORDFILTERMODEL_H_
 
+#include <QFuture>
 #include <QSortFilterProxyModel>
-#include <QVector>
 #include <QTimer>
+#include <QVector>
 
 class QStringRef;
 class KDescendantsProxyModel;
 
-namespace PlasmaPass {
-
+namespace PlasmaPass
+{
 class PasswordFilterModel : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -52,13 +53,33 @@ protected:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
+    struct PathFilter {
+        using result_type = std::pair<QModelIndex, int>;
+
+        explicit PathFilter() = default;
+        PathFilter(QString filter);
+
+        PathFilter(const PathFilter &);
+        PathFilter(PathFilter &&) noexcept;
+        PathFilter &operator=(const PathFilter &);
+        PathFilter &operator=(PathFilter &&) noexcept;
+
+        result_type operator()(const QModelIndex &index) const;
+
+        QString filter;
+
+    private:
+        void updateParts();
+        QVector<QStringRef> mParts;
+    };
+
     void delayedUpdateFilter();
 
     KDescendantsProxyModel *mFlatModel = nullptr;
-    QString mFilter;
-    QVector<QStringRef> mParts;
+    PathFilter mFilter;
     mutable QHash<QModelIndex, int> mSortingLookup;
     QTimer mUpdateTimer;
+    QFuture<QHash<QModelIndex, int>> mFuture;
 };
 
 }
